==> holehe-1.59.1.2-py3-none-any.whl: holehe/modules/cms/gravatar.py <==
from holehe.core import *
from holehe.localuseragent import *


async def gravatar(email, client, out):
    name = "gravatar"
    domain = "gravatar.com"
    method="other"
    frequent_rate_limit=False

    hashed_name = hashlib.md5(email.encode()).hexdigest()
    r = await client.get('https://gravatar.com/{hashed_name}.json')
    if r.status_code != 200:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None
    else:
        try:
            data = r.json()
            FullName = data['entry'][0]['displayName']

            others = {
                'FullName': str(FullName)+" / "+str(data['entry'][0]["profileUrl"]),
            }

            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": others})
            return None
        except BaseException:
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": True,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
            return None

==> holehe-1.60-py3-none-any.whl: holehe/modules/cms/gravatar.py <==
from holehe.core import *
from holehe.localuseragent import *


async def gravatar(email, client, out):
    name = "gravatar"
    domain = "gravatar.com"
    method="other"
    frequent_rate_limit=False

    hashed_name = hashlib.md5(email.encode()).hexdigest()
    r = await client.get(f'https://gravatar.com/{hashed_name}.json')
    if r.status_code != 200:
        out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                    "rateLimit": False,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None
    else:
        try:
            data = r.json()
            FullName = data['entry'][0]['displayName']

            others = {
                'FullName': str(FullName)+" / "+str(data['entry'][0]["profileUrl"]),
            }

            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": others})
            return None
        except BaseException:
            out.append({"name": name,"domain":domain,"method":method,"frequent_rate_limit":frequent_rate_limit,
                        "rateLimit": True,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
            return None
